import { Pipe, PipeTransform } from '@angular/core';
import { AuditSymbol } from '../models/audit-symbols';

@Pipe({ name: 'requirementSymbols' })
export class RequirementSymbolsPipe implements PipeTransform {
  transform(lines: string[]): AuditSymbol[] {
    const singleLine = lines.join(' ').trim();
    const matches = singleLine.match(/^((IP)|(IN-P)|(PL)|(R)|(<>)|\+|\-|\*)+/g);
    const symbols: AuditSymbol[] = [
      { type: 'text', text: 'IP', tooltip: 'Requirement uses in-progress credit/courses' },
      { type: 'text', text: 'IN-P', tooltip: 'Sub-requirement uses in progress credit/courses' },
      { type: 'text', text: 'PL', tooltip: 'Requirement/sub-requirement uses planned course' },
      { type: 'text', text: 'R', tooltip: 'Required sub-requirement (mandatory)' },
      { type: 'text', text: '<>', tooltip: 'Optional/other requirement in OR\'d set complete' },
      { type: 'text', text: '*', tooltip: 'Optional sub-requirement, courses assigned' },
      { type: 'icon', text: '+', icon: 'check', tooltip: 'Sub-requirement complete' },
      { type: 'icon', text: '-', icon: 'close', tooltip: 'Sub-requirement not complete' }
    ];

    if (matches && matches.length > 0) {
      const symbolString = singleLine.substr(0, matches[0].length);
      return symbols.reduce((acc, symbol) => {
        return symbolString.includes(symbol.text) ? [...acc, symbol] : acc;
      }, []);
    }

    return [];
  }
}
